@@ -114,7 +114,6 @@ QmlMainWindow::QmlMainWindow(QObject *parent)
 , regNumberSelector(NULL)
 , ciSelector(NULL)
 , statusBanner(NULL)
-, dialPage(NULL)
 , smsPage(NULL)
 , inboxDetails(NULL)
 , etCetera(NULL)
@@ -154,7 +153,13 @@ QmlMainWindow::init()
     } else {
         m_qmlStub->setParent(this);
     }
+    /*
+     * Look at the Q_INVOKABLE functions in the header and use them in QML.
+     */
     m_view->rootContext()->setContextProperty("g_qmlstub", m_qmlStub);
+    m_view->rootContext()->setContextProperty("g_mainwindow", this);
+    m_view->rootContext()->setContextProperty("g_inbox", &oInbox);
+    m_view->rootContext()->setContextProperty("g_contacts", &oContacts);
 
 #ifdef DBUS_API
     if (!initDBus ()) {
@@ -319,6 +324,11 @@ QmlMainWindow::initQmlObjects()
             break;
         }
 
+        rv = true;
+        QMetaObject::invokeMethod(mainTabGroup, "setTabsEnable",
+                                  Q_ARG(QVariant, QVariant(rv)));
+        rv = false;
+
         loginExpand = getQMLObject ("ExpandLoginDetails");
         if (NULL == loginExpand) {
             break;
@@ -328,14 +338,11 @@ QmlMainWindow::initQmlObjects()
         if (NULL == loginButton) {
             break;
         }
-        connect(loginButton, SIGNAL(clicked()),
-                this, SLOT(onLoginButtonClicked()));
 
         tfaPinDlg = getQMLObject ("TFAPinDialog");
         if (NULL == tfaPinDlg) {
             break;
         }
-        connect(tfaPinDlg, SIGNAL(done(bool)), this, SLOT(onTfaPinDlg(bool)));
 
         textUsername = getQMLObject ("TextUsername");
         if (NULL == textUsername) {
@@ -407,15 +414,6 @@ QmlMainWindow::initQmlObjects()
             break;
         }
 
-        dialPage = getQMLObject ("DialPage");
-        if (NULL == dialPage) {
-            break;
-        }
-        connect(dialPage, SIGNAL(sigCall(QString)),
-                this, SLOT(onUserCall(QString)));
-        connect(dialPage, SIGNAL(sigText(QString)),
-                this, SLOT(onUserTextBtnClicked(QString)));
-
         smsPage = getQMLObject ("SmsPage");
         if (NULL == smsPage) {
             break;
@@ -427,8 +425,6 @@ QmlMainWindow::initQmlObjects()
         if (NULL == inboxDetails) {
             break;
         }
-        connect(inboxDetails, SIGNAL(deleteEntry(QString)),
-                &oInbox, SLOT(deleteEntry(QString)));
         connect(inboxDetails, SIGNAL(replySms(QString)),
                 this, SLOT(onUserReplyToInboxEntry(QString)));
         connect(inboxDetails, SIGNAL(play()), &oVmail, SLOT(play()));
@@ -460,33 +456,21 @@ QmlMainWindow::initQmlObjects()
         if (NULL == optContactsUpdate) {
             break;
         }
-        connect(optContactsUpdate, SIGNAL(clicked()),
-                this, SLOT(onOptContactsUpdateClicked()));
 
         optInboxUpdate = getQMLObject ("OptInboxUpdate");
         if (NULL == optInboxUpdate) {
             break;
         }
-        connect(optInboxUpdate, SIGNAL(clicked()),
-                this, SLOT(onOptInboxUpdateClicked()));
 
         edContactsUpdateFreq = getQMLObject ("EdContactsUpdateFreq");
         if (NULL == edContactsUpdateFreq) {
             break;
         }
-        m_view->connectToChangeNotify(edContactsUpdateFreq,
-                                      "text",
-                                      this,
-                                      SLOT(onEdContactsUpdateTextChanged()));
 
         edInboxUpdateFreq = getQMLObject ("EdInboxUpdateFreq");
         if (NULL == edInboxUpdateFreq) {
             break;
         }
-        m_view->connectToChangeNotify(edInboxUpdateFreq,
-                                      "text",
-                                      this,
-                                      SLOT(onEdInboxUpdateTextChanged()));
 
         initDerivedQmlObjects();
 
@@ -636,6 +620,9 @@ void
 QmlMainWindow::uiLoginDone(int status, const QString & /*errStr*/)
 {
     if (ATTS_SUCCESS == status) {
+        bool val = false;
+        QMetaObject::invokeMethod(mainTabGroup, "setTabsEnable",
+                                  Q_ARG(QVariant, QVariant(val)));
         return;
     }
 }//QmlMainWindow::uiLoginDone
@@ -975,9 +962,9 @@ QmlMainWindow::onOptInboxUpdateClicked(bool updateDb /*= true*/)
 }//QmlMainWindow::onOptInboxUpdateClicked
 
 void
-QmlMainWindow::onEdContactsUpdateTextChanged()
+QmlMainWindow::onEdContactsUpdateTextChanged(const QString &text)
 {
-    quint32 mins = edContactsUpdateFreq->property ("text").toInt ();
+    quint32 mins = text.toInt ();
     if (0 == mins) {
         Q_WARN("Ignoring zero minute contact update frequency");
         return;
@@ -987,9 +974,9 @@ QmlMainWindow::onEdContactsUpdateTextChanged()
 }//QmlMainWindow::onEdContactsUpdateTextChanged
 
 void
-QmlMainWindow::onEdInboxUpdateTextChanged()
+QmlMainWindow::onEdInboxUpdateTextChanged(const QString &text)
 {
-    quint32 mins = edInboxUpdateFreq->property ("text").toInt ();
+    quint32 mins = text.toInt ();
     if (0 == mins) {
         Q_WARN("Ignoring zero minute inbox update frequency");
         return;
