@@ -6,13 +6,16 @@
 class MainWindow : public QmlMainWindow
 {
     Q_OBJECT
+
 public:
     explicit MainWindow(QObject *parent = 0);
 
-signals:
-
-public slots:
+protected:
+    QString getMainQmlPath();
+    void initDerivedQmlObjects();
 
+protected slots:
+    void setNumberInDisp(const QString &number);
 };
 
 QCoreApplication *
